@@ -1306,6 +1306,10 @@ impl ModeState for State {
                 }
                 _ => (),
             },
+            Key::Char('$') => {
+                handled_keys = true;
+                read_line::process::enter_run_mode(ctx);
+            }
             Key::Char(':') => {
                 handled_keys = true;
                 ctx.editor.enter_mode(ModeKind::Command);
