@@ -192,6 +192,8 @@ fn run_server(config: ApplicationConfig, listener: UnixListener) {
     kqueue.add(Event::Fd(listener.as_raw_fd()), 0);
     let mut kqueue_events = KqueueEvents::new();
 
+    let _ignore_server_connection_buffer_len = ServerApplication::connection_buffer_len();
+
     loop {
         let kqueue_events = kqueue.wait(&mut kqueue_events, timeout);
         if kqueue_events.len() == 0 {
@@ -257,7 +259,7 @@ fn run_server(config: ApplicationConfig, listener: UnixListener) {
                         let tag = process.tag();
                         match process.read(&mut application.ctx.platform.buf_pool) {
                             Ok(None) => (),
-                            Ok(Some(buf)) => events.push(PlatformEvent::ProcessExit { tag }),
+                            Ok(Some(buf)) => events.push(PlatformEvent::ProcessOutput { tag, buf }),
                             Err(()) => {
                                 if let Some(fd) = process.try_as_raw_fd() {
                                     kqueue.remove(Event::Fd(fd));
@@ -418,7 +420,9 @@ fn run_client(args: Args, mut connection: UnixStream) {
     }
 
     let mut keys = Vec::new();
-    let mut buf = Vec::new();
+    let buf_capacity =
+        ClientApplication::connection_buffer_len().max(ClientApplication::stdin_buffer_len());
+    let mut buf = Vec::with_capacity(buf_capacity);
 
     'main_loop: loop {
         for event in kqueue.wait(&mut kqueue_events, None) {
@@ -480,3 +484,4 @@ fn run_client(args: Args, mut connection: UnixStream) {
     drop(terminal);
     drop(application);
 }
+
